@@ -60,11 +60,11 @@ and http://janne-pekkala.blogspot.com/"""
     # chmod +x /usr/bin/mclock.py""" #Set here your pre install script
     # p.preremove="""#!/bin/sh
     # chmod +x /usr/bin/mclock.py""" #Set here your pre remove script
-    version = "0.7.0"           #Version of your software, e.g. "1.2.0" or "0.8.2"
-    build = "2"                 #Build number, e.g. "1" for the first build of this version of your software. Increment for later re-builds of the same version of your software.
+    version = "0.7.1"           #Version of your software, e.g. "1.2.0" or "0.8.2"
+    build = "1"                 #Build number, e.g. "1" for the first build of this version of your software. Increment for later re-builds of the same version of your software.
 
     # Text with changelog information to be displayed in the package "Details" tab of the Maemo Application Manager
-    changeloginformation = """ New GUI written in Qt, code simplifying (to Qt), new function to take timelapse photos and offical support for Samsung. Bugfix for postinstall script. """
+    changeloginformation = """ Fixing the bug caused by Pr 1.3 """
 
     dir_name = "src"            #Name of the subfolder containing your package source files (e.g. usr\share\icons\hicolor\scalable\myappicon.svg, usr\lib\myapp\somelib.py). We suggest to leave it named src in all projects and will refer to that in the wiki article on maemo.org
     #Thanks to DareTheHair from talk.maemo.org for this snippet that recursively builds the file list
