@@ -64,12 +64,19 @@ If this is first time you use pyKake after install, it is possible that you need
 """
 
 APP_TITLE="pyKake"
-APP_VERSION="0.7.0"
+APP_VERSION="0.7.1"
 LOGO = '/opt/pykake/pykake.png'
 BUGTRACKER= "http://talk.maemo.org/showthread.php?t=50204"
 
-import sys, osso, gst, subprocess
-from PyQt4 import QtGui, QtCore
+import sys
+
+""" Crazy hack to instantiate QApplication in PR 1.3 (From Dropn900 by Jonne Nauha)."""
+from PyQt4.QtGui import QApplication
+app = QApplication(sys.argv)
+
+import osso, gst, subprocess
+from PyQt4.QtGui import *
+from PyQt4.QtCore import *
 
 # Global variables from settings file
 CURRENT_REMOTETYPE= ""
@@ -104,35 +111,35 @@ bulbStarted = False
 bulbTime = 0
 
 # Public settings:
-sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding) # Size policy fo buttons
+sizePolicy = QSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding) # Size policy fo buttons
 
-class MainWindow(QtGui.QMainWindow): # Class for main application
+class MainWindow(QMainWindow): # Class for main application
 	def __init__(self):
-		QtGui.QMainWindow.__init__(self, None)		 # Intializing the main window
-		self.mapper = QtCore.QSignalMapper() # Intializing the Signal mapper for the program
+		QMainWindow.__init__(self, None)		 # Intializing the main window
+		self.mapper = QSignalMapper() # Intializing the Signal mapper for the program
 		
 		# Reboot notification in case of first run.
-		helpfile = QtCore.QVariant(MiscFunctions().loadQSettings("settings/help_show", True)).toBool()
+		helpfile = QVariant(MiscFunctions().loadQSettings("settings/help_show", True)).toBool()
 		if helpfile != False:
-			QtGui.QMessageBox.question(self, 'Important', MESSAGE, QtGui.QMessageBox.Ok)
+			QMessageBox.question(self, 'Important', MESSAGE, QMessageBox.Ok)
 		
 		self.resize(800, 480)
 		self.setStyleSheet(MiscFunctions().readFile(styleFile))
-		self.setWindowTitle("PyKake 0.7.0 - Qt")
+		self.setWindowTitle("%s %s" %(APP_TITLE, APP_VERSION))
 		
 		# Creating menu buttons:
-		self.mbSettings = QtGui.QAction('Settings', self)
+		self.mbSettings = QAction('Settings', self)
 		self.mbSettings.setObjectName("menuButton")
-		self.connect(self.mbSettings, QtCore.SIGNAL('triggered()'), self.settingsDialog)
+		self.connect(self.mbSettings, SIGNAL('triggered()'), self.settingsDialog)
 		
-		self.mbAbout = QtGui.QAction('About', self)
-		self.connect(self.mbAbout, QtCore.SIGNAL('triggered()'), self.aboutDialog)
+		self.mbAbout = QAction('About', self)
+		self.connect(self.mbAbout, SIGNAL('triggered()'), self.aboutDialog)
 		
-		self.mbHelp = QtGui.QAction('Help', self)
-		self.connect(self.mbHelp, QtCore.SIGNAL('triggered()'), self.helpDialog)
+		self.mbHelp = QAction('Help', self)
+		self.connect(self.mbHelp, SIGNAL('triggered()'), self.helpDialog)
 		
-		self.mbBugger = QtGui.QAction('Bugtracker', self)
-		self.connect(self.mbBugger, QtCore.SIGNAL("clicked()"), self.mapper, QtCore.SLOT("map()"))
+		self.mbBugger = QAction('Bugtracker', self)
+		self.connect(self.mbBugger, SIGNAL("clicked()"), self.mapper, SLOT("map()"))
 		self.mapper.setMapping(self.mbBugger, "bugger")
 		
 		# Creating menu
@@ -144,15 +151,15 @@ class MainWindow(QtGui.QMainWindow): # Class for main application
 		mitem.addAction(self.mbBugger)
 		
 		# Creating tabs and using tab widget as a Central widget
-		self.tabs = QtGui.QTabWidget()
-		self.tabs.TabShape(QtGui.QTabWidget.Rounded)
+		self.tabs = QTabWidget()
+		self.tabs.TabShape(QTabWidget.Rounded)
 		self.tabs.addTab(self.basicMode(), "Basic") # index = 0
 		self.tabs.addTab(self.bulbMode(), "Bulb") # index = 1
 		self.tabs.addTab(self.timedMode(), "Timed") # index = 2
 		self.tabs.addTab(self.viewerMode(), "Viewer") # index = 3
 		self.tabs.addTab(self.systemMode(), "System") # index = 4
 		
-		self.connect(self.tabs, QtCore.SIGNAL("currentChanged(int)"), self.onPageChange)
+		self.connect(self.tabs, SIGNAL("currentChanged(int)"), self.onPageChange)
 		
 		self.setCentralWidget(self.tabs)
 		
@@ -163,24 +170,24 @@ class MainWindow(QtGui.QMainWindow): # Class for main application
 		self.buttonVisibility()
 		self.tabVisibility()
 		
-		self.connect(self.mapper, QtCore.SIGNAL("mapped(const QString &)"), self.buttonClicked) # Connects signals to functions.
+		self.connect(self.mapper, SIGNAL("mapped(const QString &)"), self.buttonClicked) # Connects signals to functions.
 
 ########## Modes in tabs ##########
 
 	def basicMode(self):
-		widget = QtGui.QWidget()
-		hbox = QtGui.QHBoxLayout()
+		widget = QWidget()
+		hbox = QHBoxLayout()
 	
 		# Buttons
-		shutter = QtGui.QPushButton("Shutter")
+		shutter = QPushButton("Shutter")
 		shutter.setSizePolicy(sizePolicy)
-		self.connect(shutter, QtCore.SIGNAL('clicked()'), self.mapper, QtCore.SLOT("map()"))
+		self.connect(shutter, SIGNAL('clicked()'), self.mapper, SLOT("map()"))
 		self.mapper.setMapping(shutter, "shutter") # Gives needed value to signal mapper
 		
-		self.sec2mod = QtGui.QPushButton("Activate 2 sec mode")
+		self.sec2mod = QPushButton("Activate 2 sec mode")
 		self.sec2mod.setCheckable(True)
 		self.sec2mod.setSizePolicy(sizePolicy)
-		self.connect(self.sec2mod, QtCore.SIGNAL('clicked()'), self.mapper, QtCore.SLOT("map()"))
+		self.connect(self.sec2mod, SIGNAL('clicked()'), self.mapper, SLOT("map()"))
 		self.mapper.setMapping(self.sec2mod, "mod2sec")
 	
 		hbox.addWidget(shutter)
@@ -190,37 +197,37 @@ class MainWindow(QtGui.QMainWindow): # Class for main application
 		return widget
 
 	def bulbMode(self):
-		widget = QtGui.QWidget()
+		widget = QWidget()
 		
-		hbox = QtGui.QHBoxLayout()
+		hbox = QHBoxLayout()
 		
 		# Left side, includes only Bulb Button
-		self.bulbButton = QtGui.QPushButton("Bulb On")
+		self.bulbButton = QPushButton("Bulb On")
 		self.bulbButton.setSizePolicy(sizePolicy)
-		self.connect(self.bulbButton, QtCore.SIGNAL("clicked()"), self.mapper, QtCore.SLOT("map()"))
+		self.connect(self.bulbButton, SIGNAL("clicked()"), self.mapper, SLOT("map()"))
 		self.mapper.setMapping(self.bulbButton, "bulbButton")
 		hbox.addWidget(self.bulbButton)
 		
 		# Right side, includes Timer label, Add time and activate 2 sec mode button 
-		vbox = QtGui.QVBoxLayout()
-		self.timer = QtCore.QBasicTimer()
-		self.timeLabel = QtGui.QLabel("0:00")
-		self.timeLabel.setAlignment(QtCore.Qt.AlignHCenter | QtCore.Qt.AlignVCenter)
+		vbox = QVBoxLayout()
+		self.timer = QBasicTimer()
+		self.timeLabel = QLabel("0:00")
+		self.timeLabel.setAlignment(Qt.AlignHCenter | Qt.AlignVCenter)
 		self.timeLabel.setSizePolicy(sizePolicy)
 		vbox.addWidget(self.timeLabel)
 		
-		addButton = QtGui.QPushButton("Add time")
+		addButton = QPushButton("Add time")
 		addButton.setSizePolicy(sizePolicy)
-		self.connect(addButton, QtCore.SIGNAL("clicked()"), self.mapper, QtCore.SLOT("map()"))
+		self.connect(addButton, SIGNAL("clicked()"), self.mapper, SLOT("map()"))
 		self.mapper.setMapping(addButton, "addButton")
 		vbox.addWidget(addButton)
 		
-		self.sec2mod2 = QtGui.QPushButton("Activate 2 sec mode")
+		self.sec2mod2 = QPushButton("Activate 2 sec mode")
 		if CURRENT_REMOTETYPE != "CANON-RC1/RC5": # Hides mod2sec button from others than Canon
 			self.sec2mod2.hide() 
 		self.sec2mod2.setSizePolicy(sizePolicy)
 		self.sec2mod2.setCheckable(True)
-		self.connect(self.sec2mod2, QtCore.SIGNAL("clicked()"), self.mapper, QtCore.SLOT("map()"))
+		self.connect(self.sec2mod2, SIGNAL("clicked()"), self.mapper, SLOT("map()"))
 		self.mapper.setMapping(self.sec2mod2, "mod2sec")
 		vbox.addWidget(self.sec2mod2)
 		
@@ -230,64 +237,64 @@ class MainWindow(QtGui.QMainWindow): # Class for main application
 		return widget
 		
 	def timedMode(self):
-		widget = QtGui.QWidget()		
-		main = QtGui.QVBoxLayout()
+		widget = QWidget()		
+		main = QVBoxLayout()
 		
 		# Photo info:
-		grid = QtGui.QGridLayout()
+		grid = QGridLayout()
 		main.addLayout(grid, 1)
 		
-		label = QtGui.QLabel("Photos:")
+		label = QLabel("Photos:")
 		grid.addWidget(label, 1,0)
-		self.photoLabel = QtGui.QLabel("0")
+		self.photoLabel = QLabel("0")
 		grid.addWidget(self.photoLabel, 1,1)
 		
 		# Time info1 (ellapsed time):
-		label = QtGui.QLabel("Time ellapsed:")
+		label = QLabel("Time ellapsed:")
 		grid.addWidget(label, 1,2)
-		self.ellapsedTime = QtGui.QLabel("0:00:00")
+		self.ellapsedTime = QLabel("0:00:00")
 		grid.addWidget(self.ellapsedTime, 1,3)
 		
 		# Interval between photos:
-		label = QtGui.QLabel("Interval:")
+		label = QLabel("Interval:")
 		grid.addWidget(label, 2,0)
-		self.photoInter = QtGui.QLabel ("10 seconds")
+		self.photoInter = QLabel ("10 seconds")
 		grid.addWidget(self.photoInter, 2,1)
 		
 		# Time info2 (time left):
-		label = QtGui.QLabel("Time left:")
+		label = QLabel("Time left:")
 		grid.addWidget(label, 2,2)
-		self.timeLeft = QtGui.QLabel("0:00:00")
+		self.timeLeft = QLabel("0:00:00")
 		grid.addWidget(self.timeLeft, 2,3)
 
 		# Buttons	
-		self.addPhotos = QtGui.QPushButton("Add photos")
+		self.addPhotos = QPushButton("Add photos")
 		self.addPhotos.setSizePolicy(sizePolicy)
-		self.connect(self.addPhotos, QtCore.SIGNAL("clicked()"), self.mapper, QtCore.SLOT("map()"))
+		self.connect(self.addPhotos, SIGNAL("clicked()"), self.mapper, SLOT("map()"))
 		self.mapper.setMapping(self.addPhotos, "addPhotos")
 		
-		self.addTime = QtGui.QPushButton("Add time")
+		self.addTime = QPushButton("Add time")
 		self.addTime.setSizePolicy(sizePolicy)
-		self.connect(self.addTime, QtCore.SIGNAL("clicked()"), self.mapper, QtCore.SLOT("map()"))
+		self.connect(self.addTime, SIGNAL("clicked()"), self.mapper, SLOT("map()"))
 		self.mapper.setMapping(self.addTime, "addTime")
 		
-		self.photoTime = QtGui.QPushButton("Add time interval\nfor photos")
+		self.photoTime = QPushButton("Add time interval\nfor photos")
 		self.photoTime.setSizePolicy(sizePolicy)
-		self.connect(self.photoTime, QtCore.SIGNAL("clicked()"), self.mapper, QtCore.SLOT("map()"))
+		self.connect(self.photoTime, SIGNAL("clicked()"), self.mapper, SLOT("map()"))
 		self.mapper.setMapping(self.photoTime, "photoTime")
 
-		self.timedBulb = QtGui.QPushButton("Set bulb")
+		self.timedBulb = QPushButton("Set bulb")
 		self.timedBulb.setSizePolicy(sizePolicy)
-		self.connect(self.timedBulb, QtCore.SIGNAL("clicked()"), self.mapper, QtCore.SLOT("map()"))
+		self.connect(self.timedBulb, SIGNAL("clicked()"), self.mapper, SLOT("map()"))
 		self.mapper.setMapping(self.timedBulb, "timedBulb")
 		
-		self.startButton = QtGui.QPushButton("Start")
+		self.startButton = QPushButton("Start")
 		self.startButton.setSizePolicy(sizePolicy)
-		self.connect(self.startButton, QtCore.SIGNAL("clicked()"), self.mapper, QtCore.SLOT("map()"))
+		self.connect(self.startButton, SIGNAL("clicked()"), self.mapper, SLOT("map()"))
 		self.mapper.setMapping(self.startButton, "startTimer")
 		
 		# Button grid
-		bgrid = QtGui.QGridLayout()
+		bgrid = QGridLayout()
 		main.addLayout(bgrid, 1)
 		bgrid.addWidget(self.addPhotos, 1,0)
 		bgrid.addWidget(self.addTime, 2,0)
@@ -300,38 +307,38 @@ class MainWindow(QtGui.QMainWindow): # Class for main application
 		return widget
 		
 	def viewerMode(self):
-		widget = QtGui.QWidget()
-		hbox = QtGui.QHBoxLayout()
+		widget = QWidget()
+		hbox = QHBoxLayout()
 		
 		# Zoom buttons
-		left = QtGui.QVBoxLayout()
+		left = QVBoxLayout()
 		
-		zoomIn = QtGui.QPushButton("Zoom in") # QtGui.QIcon("icons/zoom-in.png"), "Zoom in")
+		zoomIn = QPushButton("Zoom in") # QIcon("icons/zoom-in.png"), "Zoom in")
 		zoomIn.setSizePolicy(sizePolicy)
-		self.connect(zoomIn, QtCore.SIGNAL("clicked()"), self.mapper, QtCore.SLOT("map()"))
+		self.connect(zoomIn, SIGNAL("clicked()"), self.mapper, SLOT("map()"))
 		self.mapper.setMapping(zoomIn, "zoomin")
 		left.addWidget(zoomIn)
 		
-		zoomOut = QtGui.QPushButton("Zoom out") # QtGui.QIcon("icons/zoom-out.png"), "Zoom out")
+		zoomOut = QPushButton("Zoom out") # QIcon("icons/zoom-out.png"), "Zoom out")
 		zoomOut.setSizePolicy(sizePolicy)
-		self.connect(zoomOut, QtCore.SIGNAL("clicked()"), self.mapper, QtCore.SLOT("map()"))
+		self.connect(zoomOut, SIGNAL("clicked()"), self.mapper, SLOT("map()"))
 		self.mapper.setMapping(zoomOut, "zoomout")
 		left.addWidget(zoomOut)
 		
 		hbox.addLayout(left, 0)
 		
 		# Movement buttons
-		right = QtGui.QVBoxLayout()
+		right = QVBoxLayout()
 		
-		previous = QtGui.QPushButton("Previous") # QtGui.QIcon("icons/arrow-left-big.png"), "Previous")
+		previous = QPushButton("Previous") # QIcon("icons/arrow-left-big.png"), "Previous")
 		previous.setSizePolicy(sizePolicy)
-		self.connect(previous, QtCore.SIGNAL("clicked()"), self.mapper, QtCore.SLOT("map()"))
+		self.connect(previous, SIGNAL("clicked()"), self.mapper, SLOT("map()"))
 		self.mapper.setMapping(previous, "previous")
 		right.addWidget(previous)
 		
-		next = QtGui.QPushButton("Next") # QtGui.QIcon("icons/arrow-right.png"), "Next")
+		next = QPushButton("Next") # QIcon("icons/arrow-right.png"), "Next")
 		next.setSizePolicy(sizePolicy)
-		self.connect(next, QtCore.SIGNAL("clicked()"), self.mapper, QtCore.SLOT("map()"))
+		self.connect(next, SIGNAL("clicked()"), self.mapper, SLOT("map()"))
 		self.mapper.setMapping(next, "next")
 		right.addWidget(next)
 		
@@ -342,34 +349,34 @@ class MainWindow(QtGui.QMainWindow): # Class for main application
 		return widget
 
 	def systemMode(self):
-		widget  = QtGui.QWidget()
+		widget  = QWidget()
 
-		griddy = QtGui.QGridLayout()
+		griddy = QGridLayout()
 		
-		settingsButton = QtGui.QPushButton("Settings")
+		settingsButton = QPushButton("Settings")
 		settingsButton.setSizePolicy(sizePolicy)
-		self.connect(settingsButton, QtCore.SIGNAL("clicked()"), self.settingsDialog)
+		self.connect(settingsButton, SIGNAL("clicked()"), self.settingsDialog)
 		griddy.addWidget(settingsButton, 1,0)
 		
-		aboutButton = QtGui.QPushButton("About")
+		aboutButton = QPushButton("About")
 		aboutButton.setSizePolicy(sizePolicy)
-		self.connect(aboutButton, QtCore.SIGNAL("clicked()"), self.aboutDialog)
+		self.connect(aboutButton, SIGNAL("clicked()"), self.aboutDialog)
 		griddy.addWidget(aboutButton, 2,0)
 		
-		helpButton = QtGui.QPushButton("Help")
+		helpButton = QPushButton("Help")
 		helpButton.setSizePolicy(sizePolicy)
-		self.connect(helpButton, QtCore.SIGNAL("clicked()"), self.helpDialog)
+		self.connect(helpButton, SIGNAL("clicked()"), self.helpDialog)
 		griddy.addWidget(helpButton, 3,0)
 		
-		bugButton = QtGui.QPushButton("Bugtracker")
+		bugButton = QPushButton("Bugtracker")
 		bugButton.setSizePolicy(sizePolicy)
-		self.connect(bugButton, QtCore.SIGNAL("clicked()"), self.mapper, QtCore.SLOT("map()"))
+		self.connect(bugButton, SIGNAL("clicked()"), self.mapper, SLOT("map()"))
 		self.mapper.setMapping(bugButton, "bugger")
 		griddy.addWidget(bugButton, 1,1)
 		
-		exitButton = QtGui.QPushButton("Exit")
+		exitButton = QPushButton("Exit")
 		exitButton.setSizePolicy(sizePolicy)
-		self.connect(exitButton, QtCore.SIGNAL("clicked()"), self.mapper, QtCore.SLOT("map()"))
+		self.connect(exitButton, SIGNAL("clicked()"), self.mapper, SLOT("map()"))
 		self.mapper.setMapping(exitButton, "exit")
 		griddy.addWidget(exitButton, 2,1, 3,1)
 		
@@ -508,21 +515,21 @@ class MainWindow(QtGui.QMainWindow): # Class for main application
 	def addTimeDialog(self):
 		self.checker = self.tabs.currentIndex() # Using the index of current tab to select correct layouts and return functions
 
-		self.dial = QtGui.QDialog()
+		self.dial = QDialog()
 		self.dial.setWindowTitle("Add time")
-		mainBox = QtGui.QHBoxLayout()
+		mainBox = QHBoxLayout()
 		
-		hbox = QtGui.QHBoxLayout()
+		hbox = QHBoxLayout()
 		
 		if self.checker == 2: # If used from timed mode, adds hour box
-			self.hourBox = QtGui.QComboBox()
+			self.hourBox = QComboBox()
 			self.hourDict = {}
 			for i in range(25):
 				self.hourDict["%s hour" %i] = int(i)
 				self.hourBox.addItem("%s hour" %i)
 			hbox.addWidget(self.hourBox)
 				
-		self.minBox = QtGui.QComboBox()
+		self.minBox = QComboBox()
 		self.minDict = {}
 		for i in range(61):
 			if self.checker == 2 and i == 60: # In timed mode, we only need 59 minutes, not 60 or more.
@@ -531,7 +538,7 @@ class MainWindow(QtGui.QMainWindow): # Class for main application
 			self.minBox.addItem("%s min" %i)
 		hbox.addWidget(self.minBox)
 		
-		self.secBox = QtGui.QComboBox()
+		self.secBox = QComboBox()
 		self.secDict = {}
 		for i in range(60):
 			self.secDict["%s sec" %i] = int(i)
@@ -540,9 +547,9 @@ class MainWindow(QtGui.QMainWindow): # Class for main application
 		
 		mainBox.addLayout(hbox, 0)
 		
-		buttonBox = QtGui.QDialogButtonBox(QtCore.Qt.Vertical)
-		button1 = QtGui.QDialogButtonBox.Save
-		button2 = QtGui.QDialogButtonBox.Cancel
+		buttonBox = QDialogButtonBox(Qt.Vertical)
+		button1 = QDialogButtonBox.Save
+		button2 = QDialogButtonBox.Cancel
 		buttonBox.addButton(button1)
 		buttonBox.addButton(button2)
 
@@ -581,26 +588,26 @@ class MainWindow(QtGui.QMainWindow): # Class for main application
 
 ############# Photo selection dialog #############
 	def addPhotosDialog(self):
-		self.dial = QtGui.QDialog()
+		self.dial = QDialog()
 		self.dial.setWindowTitle("Give the number of photos")
-		mainBox = QtGui.QHBoxLayout()
+		mainBox = QHBoxLayout()
 		
-		vbox = QtGui.QVBoxLayout()
+		vbox = QVBoxLayout()
 		
-		self.slider = QtGui.QSlider(QtCore.Qt.Horizontal)
+		self.slider = QSlider(Qt.Horizontal)
 		self.slider.setRange(0, 1000)
 		vbox.addWidget(self.slider)
-		self.connect(self.slider, QtCore.SIGNAL('valueChanged(int)'), self.changeSpinValue)
-		self.spin = QtGui.QSpinBox()
-		self.connect(self.spin, QtCore.SIGNAL('valueChanged(int)'), self.changeSliderValue)
+		self.connect(self.slider, SIGNAL('valueChanged(int)'), self.changeSpinValue)
+		self.spin = QSpinBox()
+		self.connect(self.spin, SIGNAL('valueChanged(int)'), self.changeSliderValue)
 		self.spin.setRange(0, 1000)
 		vbox.addWidget(self.spin)
 			
 		mainBox.addLayout(vbox, 0)
 
-		buttonBox = QtGui.QDialogButtonBox(QtCore.Qt.Vertical)
-		button1 = QtGui.QDialogButtonBox.Save
-		button2 = QtGui.QDialogButtonBox.Cancel
+		buttonBox = QDialogButtonBox(Qt.Vertical)
+		button1 = QDialogButtonBox.Save
+		button2 = QDialogButtonBox.Cancel
 		buttonBox.addButton(button1)
 		buttonBox.addButton(button2)
 
@@ -630,19 +637,19 @@ class MainWindow(QtGui.QMainWindow): # Class for main application
 
 ############### Bulb selector ###################
 	def bulbSelectDialog(self):
-		self.dial = QtGui.QDialog()
+		self.dial = QDialog()
 		self.dial.setWindowTitle("Give the time for bulb")
-		mainBox = QtGui.QHBoxLayout()
+		mainBox = QHBoxLayout()
 		
-		hbox = QtGui.QHBoxLayout()
-		self.minBox = QtGui.QComboBox()
+		hbox = QHBoxLayout()
+		self.minBox = QComboBox()
 		self.minDict = {}
 		for i in range(61):
 			self.minDict["%s min" %i] = int(i)
 			self.minBox.addItem("%s min" %i)
 		hbox.addWidget(self.minBox)
 		
-		self.secBox = QtGui.QComboBox()
+		self.secBox = QComboBox()
 		self.secDict = {}
 		for i in range(60):
 			self.secDict["%s sec" %i] = int(i)
@@ -651,9 +658,9 @@ class MainWindow(QtGui.QMainWindow): # Class for main application
 
 		mainBox.addLayout(hbox, 0)
 
-		buttonBox = QtGui.QDialogButtonBox(QtCore.Qt.Vertical)
-		button1 = QtGui.QDialogButtonBox.Save
-		button2 = QtGui.QDialogButtonBox.Cancel
+		buttonBox = QDialogButtonBox(Qt.Vertical)
+		button1 = QDialogButtonBox.Save
+		button2 = QDialogButtonBox.Cancel
 		buttonBox.addButton(button1)
 		buttonBox.addButton(button2)
 
@@ -684,27 +691,27 @@ class MainWindow(QtGui.QMainWindow): # Class for main application
 		
 ##### Photo time interval selector #####	
 	def addIntervalDialog(self):
-		self.dial = QtGui.QDialog()
+		self.dial = QDialog()
 		self.dial.setWindowTitle("Add time between photos")
-		mainBox = QtGui.QHBoxLayout()
+		mainBox = QHBoxLayout()
 		
-		hbox = QtGui.QHBoxLayout()
+		hbox = QHBoxLayout()
 
-		self.hourBox = QtGui.QComboBox()
+		self.hourBox = QComboBox()
 		self.hourDict = {}
 		for i in range(24):
 			self.hourDict["%s hour" %i] = int(i)
 			self.hourBox.addItem("%s hour" %i)
 		hbox.addWidget(self.hourBox)
 				
-		self.minBox = QtGui.QComboBox()
+		self.minBox = QComboBox()
 		self.minDict = {}
 		for i in range(60):
 			self.minDict["%s min" %i] = int(i)
 			self.minBox.addItem("%s min" %i)
 		hbox.addWidget(self.minBox)
 		
-		self.secBox = QtGui.QComboBox()
+		self.secBox = QComboBox()
 		self.secDict = {}
 		for i in range(60):
 			self.secDict["%s sec" %i] = int(i)
@@ -713,9 +720,9 @@ class MainWindow(QtGui.QMainWindow): # Class for main application
 		
 		mainBox.addLayout(hbox, 0)
 		
-		buttonBox = QtGui.QDialogButtonBox(QtCore.Qt.Vertical)
-		button1 = QtGui.QDialogButtonBox.Save
-		button2 = QtGui.QDialogButtonBox.Cancel
+		buttonBox = QDialogButtonBox(Qt.Vertical)
+		button1 = QDialogButtonBox.Save
+		button2 = QDialogButtonBox.Cancel
 		buttonBox.addButton(button1)
 		buttonBox.addButton(button2)
 
@@ -925,46 +932,46 @@ class MainWindow(QtGui.QMainWindow): # Class for main application
 		
 ######### Settings dialog #########
 	def settingsDialog(self):
-		self.dialog = QtGui.QDialog()
-		mainBox = QtGui.QHBoxLayout()
+		self.dialog = QDialog()
+		mainBox = QHBoxLayout()
 		self.dialog.setWindowTitle("Settings")
 		
-		vboxy = QtGui.QVBoxLayout()
+		vboxy = QVBoxLayout()
 		
 		mainBox.addLayout(vboxy, 1)
-		widget = QtGui.QWidget()
-		vbox = QtGui.QVBoxLayout()
+		widget = QWidget()
+		vbox = QVBoxLayout()
 		
-		area = QtGui.QScrollArea()
+		area = QScrollArea()
 		area.setWidgetResizable(True)
-		area.setSizePolicy( QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
+		area.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
 		
 		widget.setLayout(vbox)
 		area.setWidget(widget)
 		vboxy.addWidget(area)
 		
 		# Cameras:
-		label = QtGui.QLabel("Select camera:")
+		label = QLabel("Select camera:")
 		vbox.addWidget(label)
 		
-		self.cameraGroup = QtGui.QButtonGroup()
-		cbox = QtGui.QVBoxLayout()
-		hbox = QtGui.QHBoxLayout()
+		self.cameraGroup = QButtonGroup()
+		cbox = QVBoxLayout()
+		hbox = QHBoxLayout()
 		
-		canon = QtGui.QRadioButton("Canon")
+		canon = QRadioButton("Canon")
 		self.cameraGroup.addButton(canon)
 		hbox.addWidget(canon)
 		
-		nikon = QtGui.QRadioButton("Nikon")
+		nikon = QRadioButton("Nikon")
 		self.cameraGroup.addButton(nikon)
 		hbox.addWidget(nikon)
 		
-		olympus = QtGui.QRadioButton("Olympus")
+		olympus = QRadioButton("Olympus")
 		self.cameraGroup.addButton(olympus)
 		hbox.addWidget(olympus)
 		cbox.addLayout(hbox,1)
 		
-		pentax = QtGui.QRadioButton("Pentax and Samsung")
+		pentax = QRadioButton("Pentax and Samsung")
 		self.cameraGroup.addButton(pentax)
 		cbox.addWidget(pentax)
 		
@@ -979,25 +986,25 @@ class MainWindow(QtGui.QMainWindow): # Class for main application
 		
 		# /Cameras	
 		# Beeb interval
-		label = QtGui.QLabel("Select beeb interval:")
+		label = QLabel("Select beeb interval:")
 		vbox.addWidget(label)
 		
-		self.beebGroup = QtGui.QButtonGroup()
-		hbox = QtGui.QHBoxLayout()
+		self.beebGroup = QButtonGroup()
+		hbox = QHBoxLayout()
 		
-		t30sec = QtGui.QRadioButton("30 Sec")
+		t30sec = QRadioButton("30 Sec")
 		self.beebGroup.addButton(t30sec)
 		hbox.addWidget(t30sec)
 		
-		t1min = QtGui.QRadioButton("1 Min")
+		t1min = QRadioButton("1 Min")
 		self.beebGroup.addButton(t1min)
 		hbox.addWidget(t1min)
 		
-		t10min = QtGui.QRadioButton("10 Min")
+		t10min = QRadioButton("10 Min")
 		self.beebGroup.addButton(t10min)
 		hbox.addWidget(t10min)
 		
-		tOff = QtGui.QRadioButton("Off")
+		tOff = QRadioButton("Off")
 		self.beebGroup.addButton(tOff)
 		hbox.addWidget(tOff)
 		
@@ -1009,18 +1016,18 @@ class MainWindow(QtGui.QMainWindow): # Class for main application
 		elif TIME2BEEB == "0": tOff.toggle()
 		else: tOff.toggle()
 		
-		self.restartNotify = QtGui.QCheckBox("Show restart notify in start up")
-		if QtCore.QVariant(MiscFunctions().loadQSettings("settings/help_show", True)).toBool() == True: 
+		self.restartNotify = QCheckBox("Show restart notify in start up")
+		if QVariant(MiscFunctions().loadQSettings("settings/help_show", True)).toBool() == True: 
 			self.restartNotify.setChecked(True)
 		vbox.addWidget(self.restartNotify)
 		
-		self.fullscreenSelect = QtGui.QCheckBox("Use Fullscreen mode\nNeeds restart to get active")
+		self.fullscreenSelect = QCheckBox("Use Fullscreen mode\nNeeds restart to get active")
 		if USEFULLSCREEN == True: self.fullscreenSelect.setChecked(True)
 		vbox.addWidget(self.fullscreenSelect)
 		
-		buttonBox = QtGui.QDialogButtonBox(QtCore.Qt.Vertical)
-		button1 = QtGui.QDialogButtonBox.Save
-		button2 = QtGui.QDialogButtonBox.Cancel
+		buttonBox = QDialogButtonBox(Qt.Vertical)
+		button1 = QDialogButtonBox.Save
+		button2 = QDialogButtonBox.Cancel
 		buttonBox.addButton(button1)
 		buttonBox.addButton(button2)
 		
@@ -1035,7 +1042,7 @@ class MainWindow(QtGui.QMainWindow): # Class for main application
 		
 	def setSettings(self):
 		global CURRENT_REMOTETYPE, TIME2BEEB, USEFULLSCREEN
-		settings = QtCore.QSettings("pyKake", "pyKake")
+		settings = QSettings("pyKake", "pyKake")
 		
 		cam = self.cameraGroup.checkedButton()
 		if  cam.text() == "Canon": remote = "CANON-RC1/RC5"
@@ -1069,49 +1076,49 @@ class MainWindow(QtGui.QMainWindow): # Class for main application
 
 ########## Other dialogs ##########
 	def aboutDialog(self):
-		dialog = QtGui.QDialog()
-		dialog.setWindowTitle("About pyKake 0.7.0")
-		mainbox = QtGui.QVBoxLayout()
+		dialog = QDialog()
+		dialog.setWindowTitle("About %s %s" %(APP_TITLE, APP_VERSION))
+		mainbox = QVBoxLayout()
 		
-		tabby = QtGui.QTabWidget()
+		tabby = QTabWidget()
 		
 		# Info tab
-		area1 = QtGui.QScrollArea()
+		area1 = QScrollArea()
 		area1.setWidgetResizable(True)
-		area1.setSizePolicy( QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
+		area1.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
 		
-		info = QtGui.QWidget()
-		vbox = QtGui.QVBoxLayout()
-		img = QtGui.QPixmap(LOGO)
-		icon = QtGui.QLabel(self)
+		info = QWidget()
+		vbox = QVBoxLayout()
+		img = QPixmap(LOGO)
+		icon = QLabel(self)
 		icon.setPixmap(img)
-		icon.setAlignment(QtCore.Qt.AlignHCenter)
+		icon.setAlignment(Qt.AlignHCenter)
 		vbox.addWidget(icon)
 		
-		text = QtGui.QLabel("<div  align=\"center\"><h3>pyKake 0.7.0</h3><b><p>All logos and trademarks are property<br/>of their respective owners and are used<br/>for informational purposes only.</p></b><i>Copyright 2010 &copy; Janne Pekkala</i></div>")
+		text = QLabel("<div  align=\"center\"><h3>%s %s</h3><b><p>All logos and trademarks are property<br/>of their respective owners and are used<br/>for informational purposes only.</p></b><i>Copyright 2010 &copy; Janne Pekkala</i></div>" %(APP_TITLE, APP_VERSION))
 		vbox.addWidget(text)
 		info.setLayout(vbox)
 		area1.setWidget(info)
 		tabby.addTab(area1, "Info")
 		
 		# Developers tab
-		devs = QtGui.QWidget()
-		vbox = QtGui.QVBoxLayout()
+		devs = QWidget()
+		vbox = QVBoxLayout()
 		text = "<h3>Programming:</h3> Janne Pekkala <yabbapappa@gmail.com> <h3>Graphics:</h3> <b>Program icon:</b> Tomi Taipaleenm&auml;ki <br/>" # <b>Other icons:</b> From Open Icon Library <http://openiconlibrary.sourceforge.net/>"
-		label = QtGui.QLabel(text)
+		label = QLabel(text)
 		vbox.addWidget(label)
 		devs.setLayout(vbox)
 		tabby.addTab(devs, "Developers")
 		
 		# License tab
 
-		area2 = QtGui.QScrollArea()
+		area2 = QScrollArea()
 		area2.setWidgetResizable(True)
-		area2.setSizePolicy( QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
+		area2.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
 		
-		lic = QtGui.QWidget()
-		vbox = QtGui.QVBoxLayout()
-		label = QtGui.QLabel(LICENSE)
+		lic = QWidget()
+		vbox = QVBoxLayout()
+		label = QLabel(LICENSE)
 		vbox.addWidget(label)
 		lic.setLayout(vbox)
 		area2.setWidget(lic)
@@ -1124,72 +1131,72 @@ class MainWindow(QtGui.QMainWindow): # Class for main application
 		dialog.exec_()
 
 	def helpDialog(self):
-		dialog = QtGui.QDialog()
+		dialog = QDialog()
 		dialog.setWindowTitle("Help")
-		mainbox = QtGui.QVBoxLayout()
+		mainbox = QVBoxLayout()
 		
-		tabby = QtGui.QTabWidget()
+		tabby = QTabWidget()
 		
 		# Help: Settings
-		area1 = QtGui.QScrollArea()
+		area1 = QScrollArea()
 		area1.setWidgetResizable(True)
-		area1.setSizePolicy( QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
+		area1.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
 		
-		settings = QtGui.QWidget()
-		vbox = QtGui.QVBoxLayout()
-		label = QtGui.QLabel(SETTINGS)
+		settings = QWidget()
+		vbox = QVBoxLayout()
+		label = QLabel(SETTINGS)
 		vbox.addWidget(label)
 		settings.setLayout(vbox)
 		area1.setWidget(settings)
 		tabby.addTab(area1, "Settings")
 		
 		# Help: Basic
-		area2 = QtGui.QScrollArea()
+		area2 = QScrollArea()
 		area2.setWidgetResizable(True)
-		area2.setSizePolicy( QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
+		area2.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
 		
-		basic = QtGui.QWidget()
-		vbox = QtGui.QVBoxLayout()
-		label = QtGui.QLabel(BASIC)
+		basic = QWidget()
+		vbox = QVBoxLayout()
+		label = QLabel(BASIC)
 		vbox.addWidget(label)
 		basic.setLayout(vbox)
 		area2.setWidget(basic)
 		tabby.addTab(area2, "Basic")
 		
 		# Help: Bulb
-		area3 =QtGui.QScrollArea()
+		area3 =QScrollArea()
 		area3.setWidgetResizable(True)
-		area3.setSizePolicy( QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
+		area3.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
 		
-		bulb = QtGui.QWidget()
-		vbox = QtGui.QVBoxLayout()
-		label = QtGui.QLabel(BULB)
+		bulb = QWidget()
+		vbox = QVBoxLayout()
+		label = QLabel(BULB)
 		vbox.addWidget(label)
 		bulb.setLayout(vbox)
 		area3.setWidget(bulb)
 		tabby.addTab(area3, "Bulb")
 		
 		# Help: Viewer
-		area4 = QtGui.QScrollArea()
+		area4 = QScrollArea()
 		area4.setWidgetResizable(True)
-		area4.setSizePolicy( QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
+		area4.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
 		
-		viewer = QtGui.QWidget()
-		vbox = QtGui.QVBoxLayout()
-		label = QtGui.QLabel(VIEWER)
+		viewer = QWidget()
+		vbox = QVBoxLayout()
+		label = QLabel(VIEWER)
 		vbox.addWidget(label)
 		viewer.setLayout(vbox)
 		area4.setWidget(viewer)
 		tabby.addTab(area4, "Viewer")
 
 		# Help: Supported cameras
-		area5 = QtGui.QScrollArea()
+		area5 = QScrollArea()
 		area5.setWidgetResizable(True)
-		area5.setSizePolicy( QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
+		area5.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
 		
-		supCams = QtGui.QWidget()
-		vbox = QtGui.QVBoxLayout()
-		label = QtGui.QLabel(REMOTES)
+		supCams = QWidget()
+		vbox = QVBoxLayout()
+		label = QLabel(REMOTES)
 		vbox.addWidget(label)
 		supCams.setLayout(vbox)
 		area5.setWidget(supCams)
@@ -1215,7 +1222,7 @@ class MiscFunctions:
 		lircing.wait()
 
 	def loadQSettings(self, path, default): # Reading QSettings
-		settings = QtCore.QSettings("pyKake", "pyKake")
+		settings = QSettings("pyKake", "pyKake")
 		value = settings.value(path, default) # path == location of the value | default == default value (failback)
 		return value
 	
@@ -1224,24 +1231,24 @@ class MiscFunctions:
 		sys.exit()
 	
 	def readFile(self, fileName):
-		file = QtCore.QFile(fileName)
+		file = QFile(fileName)
 		
-		if not file.open(QtCore.QFile.ReadOnly | QtCore.QFile.Text):
+		if not file.open(QFile.ReadOnly | QFile.Text):
 			print "Problems while loading file."
 		
-		data = QtCore.QTextStream(file)
+		data = QTextStream(file)
 		text = data.readAll()
 		return text
 
 	def loadSettings(self): # Reloading settings from conf file at /home/user/.config/pyKake/pyKake.conf
 		 global CURRENT_REMOTETYPE, TIME2BEEB, USEFULLSCREEN
-		 CURRENT_REMOTETYPE = QtCore.QVariant(MiscFunctions().loadQSettings("settings/camera", "None")).toString()
-		 TIME2BEEB = QtCore.QVariant(MiscFunctions().loadQSettings("settings/beebtime", "None")).toString()
-		 USEFULLSCREEN = QtCore.QVariant(MiscFunctions().loadQSettings("settings/fullscreen", True)).toBool()
+		 CURRENT_REMOTETYPE = QVariant(MiscFunctions().loadQSettings("settings/camera", "None")).toString()
+		 TIME2BEEB = QVariant(MiscFunctions().loadQSettings("settings/beebtime", "None")).toString()
+		 USEFULLSCREEN = QVariant(MiscFunctions().loadQSettings("settings/fullscreen", True)).toBool()
 		 
-class player (QtCore.QThread):
+class player (QThread):
 	def run(self):
-		QtCore.QThread.__init__(self)
+		QThread.__init__(self)
 		global beebRun
 		player = gst.element_factory_make("playbin","player")
 		player.set_property('uri', globURI)
@@ -1308,7 +1315,7 @@ class digitalCamera: # This is class where commands from GUI are translated read
 
 ####### Running the Application #######
 
-app = QtGui.QApplication(sys.argv)
+#app = QApplication(sys.argv) # Currently out of use (since v. 0.7.1), because Pr 1.3 causing problems at the moment (2.11.2010).
 MiscFunctions().loadSettings()
 MiscFunctions().controlLircd("start")
 
